/* init.c -- initialization code
   Copyright 1997-98 Michael Callahan
   Copyright 1999 Carnegie Mellon University
   This program is free software.  You may copy it according
   to the conditions of the GNU General Public License version 2.0
   or later; see the file COPYING in the source directory.
*/


#include <string.h>
#pragma intrinsic (memset)

#include "MC.h"


#pragma VxD_LOCKED_DATA_SEG
#pragma VxD_LOCKED_CODE_SEG

static char copyright[] = "Copyright 1997 Michael Callahan\n";


#define MCSTUB_DEVICE_ID			0x1234
Begin_Service_Table(MCSTUB, none)
#define MCSTUB_Service(X) Declare_Service(X, none)
MCSTUB_Service(MCSTUB_Get_Version)
MCSTUB_Service(_MCSTUB_Get_ConnectNetResource)
MCSTUB_Service(_MCSTUB_Set_ConnectNetResource)
MCSTUB_Service(_MCSTUB_Get_AsyncEvent)
MCSTUB_Service(_MCSTUB_Set_AsyncEvent)
MCSTUB_Service(_MCSTUB_Get_ProviderId)
End_Service_Table(MCSTUB, none)


#pragma warning(disable: 4035)
DWORD MCSTUB_Get_Version()
{
	DWORD res;
	VxDCall(MCSTUB_Get_Version)
	_asm jnc noerror
	_asm mov eax, 0h
	_asm noerror:
	_asm mov [res], eax
	return res;
}

__declspec(naked) DWORD VXDINLINE MCSTUB_Get_ConnectNetResource (void)
{
	VxDJmp(_MCSTUB_Get_ConnectNetResource)
}
__declspec(naked) DWORD VXDINLINE MCSTUB_Set_ConnectNetResource (int (*f) (pioreq))
{
	VxDJmp(_MCSTUB_Set_ConnectNetResource)
}

__declspec(naked) DWORD VXDINLINE MCSTUB_Get_AsyncEvent (void)
{
	VxDJmp(_MCSTUB_Get_AsyncEvent)
}
__declspec(naked) DWORD VXDINLINE MCSTUB_Set_AsyncEvent (void (*f) (PAEP))
{
	VxDJmp(_MCSTUB_Set_AsyncEvent)
}

__declspec(naked) DWORD VXDINLINE MCSTUB_Get_ProviderId (void)
{
	VMMJmp(_MCSTUB_Get_ProviderId)
}

#pragma warning(default: 4035)

/* #pragma VxD_INIT_DATA_SEG */
/* #pragma VxD_INIT_CODE_SEG */

/* symbols defined in MCvxd.asm */
extern DWORD BSSstart, BSSend;

void OnAsyncEvent(PAEP);
void OnTimeoutEvent();

DWORD dwTimeoutEventHdl = 0;

BOOL OnDeviceInit ()
{
	/* clear bss segment */
	memset (&BSSstart, 0, ((char *)&BSSend) - ((char *)&BSSstart));

	/* check that MCSTUB is loaded */
	if (!MCSTUB_Get_Version())
		return FALSE;

	if (MCSTUB_Get_ConnectNetResource() || MCSTUB_Get_AsyncEvent())
		return FALSE;

	/* set timeout event for 4 seconds (=4000msec) from now */
	dwTimeoutEventHdl = Set_Global_Time_Out (OnTimeoutEvent,
		4000, 0);
	if (!dwTimeoutEventHdl)
		return FALSE;

	MCSTUB_Set_ConnectNetResource (ConnectNetResource);
	/* MCSTUB_Set_AsyncEvent (OnAsyncEvent); */
	if (MCSTUB_Get_ConnectNetResource() != (DWORD) ConnectNetResource /* ||
		MCSTUB_Get_AsyncEvent() != (DWORD) OnAsyncEvent */ ) {
		MCSTUB_Set_ConnectNetResource (NULL);
		MCSTUB_Set_AsyncEvent (NULL);
		return FALSE;
	}

	uiProviderId = MCSTUB_Get_ProviderId();

	return TRUE;
}

void OnTimeoutEvent ()
{
	calls[0]++;
	heartbeat();
	dwTimeoutEventHdl = Set_Global_Time_Out (OnTimeoutEvent,
		4000, 0);
}

void OnAsyncEvent (PAEP pAEP)
{
	if (pAEP->AEP_func == AEP_4_SECS) {
		calls[0]++;
		heartbeat();
	}
	pAEP->AEP_result = AEP_SUCCESS;
}

int inUseCount = 0;

BOOL OnDeviceExit ()
{
/*	if (inUseCount)
		return FALSE; */

	MCSTUB_Set_ConnectNetResource (NULL);
	MCSTUB_Set_AsyncEvent (NULL);
	Cancel_Time_Out(dwTimeoutEventHdl);
	return TRUE;
}

