//
// OSRNP.H -- OSR Sample Network Provider definitions
//
// Developed by OSR Open Systems Resources, Inc.
//
// (C) Copyright 1995, 1996 OSR Open Systems Resources, Inc.
// All Rights Reserved.
//
#ifndef _OSRNP_
#define _OSRNP_

#include <winnetwk.h>        // Win32 definitions
#include "osrnfsdef.h"        // OSR NFS File System definitions
#include "wrapper-ioctl.h"    // OSR Wrapper IOCTL definitions

#include <ntverp.h>


#if VER_PRODUCTBUILD == 1057
    #define NT_351 (1)
#else
    #define NT_40  (1)
#endif

//
// Defines
//
#define    OSR_NP_VERMAJ        1        // Major version
#define    OSR_NP_VERMIN        0        // Minor version
//
// Swap macros
//
#define    SWAP_ULONG(u)    ((u<<24)|((u<<8)&0xff0000)|((u>>8)&0xff00)|(u>>24))
#define    SWAPL(x)    SWAP_ULONG(((ULONG)(x)))
#define    ntohl(Long)        SWAPL(Long)
#define    htonl(Long)        SWAPL(Long)

//
// Ennumeration
//
#define OSRNP_ENUM_NONE    0xFFFFFFFF

//
// Values between 0 and 0xFFFF0000 represent
// a server index, indicating that we want to
// enum the resources on the corresponding server.
//
#define OSRNP_ENUM_SERVERS     0xFFFF0001
#define OSRNP_ENUM_CONNECTED 0xFFFF0002

    


#if NT_40

    #include    <npapi.h>

    //
    // OSR Network Type (NOT registered with Microsoft)
    // Randomly set to be greater than the highest value in winnetwk.h
    // However note that this DOES need to be unique on the system,
    // otherwise MPR gets confused.
    //
    #define    OSR_NET_TYPE            0x001F0000

    //
    // OSR Driver Version
    //
    #define OSR_DRIVER_VERSION        ((OSR_NP_VERMAJ<<8) || OSR_NP_VERMIN)

    //
    // Version of Nework Provider Spec we implement
    // High word = major, low word = minor
    //
    #define OSR_SPEC_VERSION    WNNC_SPEC_VERSION

    //
    // OSR Network Type (NOT registered with Microsoft)
    // Randowmly set to be greater than the highest value in winnetwk.h
    //
    #define    OSR_NET_TYPE            0x001F0000

    #define    OSR_USER                WNNC_USR_GETUSER

    #define    OSR_START_NOW            0x0001    // ms to startup (0x00 = disabled)
    #define OSR_START_DISABLED      0x0000     //               (0x01 = started now)
    #define OSR_START_UNKNOWN       0xFFFFFFFF  // 0XFFFFFFFF = beats me


#else       // NT_V40

//
// Get Capabilities
//
#define WNNC_SPEC_VERSION        0x0001
    //
    // Version of Nework Provider Spec we implement
    // High word = major, low word = minor
    #define OSR_SPEC_VERSION        0x40000

#define WNNC_NET_TYPE            0x0002
    //
    // OSR Network Type (NOT registered with Microsoft)
    // Randowmly set to be greater than the highest value in winnetwk.h
    //
    #define    OSR_NET_TYPE            0x001F0000

#define WNNC_DRIVER_VERSION        0x0003
    //
    // OSR Driver Version
    //
    #define OSR_DRIVER_VERSION        ((OSR_NP_VERMAJ<<8) || OSR_NP_VERMIN)

#define WNNC_USER                0x0004
    #define WNNC_USR_GETUSER        0x0001
    #define    OSR_USER                WNNC_USR_GETUSER

#define WNNC_CONNECTION            0x0006
    #define  WNNC_CON_ADDCONNECTION        0x0001
    #define  WNNC_CON_CANCELCONNECTION    0x0002
    #define  WNNC_CON_GETCONNECTIONS    0x0004
    #define  WNNC_CON_ADDCONNECTION3    0x0008

#define WNNC_DIALOG                0x0008
    #define WNNC_DLG_DEVICEMODE            0x0001
    #define WNNC_DLG_PROPERTYDIALOG        0x0020        // implies property text, too
    #define WNNC_DLG_SEARCHDIALOG        0x0040
    #define WNNC_DLG_FORMATNETWORKNAME    0x0080
    #define    WNNC_DLG_PERMISSIONEDITOR    0x0100

#define WNNC_ADMIN                0x0009
    #define    WNNC_ADM_GETDIRECTORYTYPE    0x0001
    #define    WNNC_ADM_DIRECTORYNOTIFY    0x0002

#define WNNC_ENUMERATION        0x000b
    #define    WNNC_ENUM_GLOBAL            0x0001
    #define    WNNC_ENUM_LOCAL                0x0002

#define WNNC_START                0x000c
    #define    OSR_START_NOW            0x0001    // ms to startup (0x00 = disabled)
    #define OSR_START_DISABLED      0x0000     //               (0x01 = started now)
    #define OSR_START_UNKNOWN       0xFFFFFFFF  // 0XFFFFFFFF = beats me
#endif    // NT_V40

#endif // ndef _OSRNP_
